/** \file
 *  This C header file was generated by $ANTLR version 3.4
 *
 *     -  From the grammar source file : MySQL.g
 *     -                            On : 2016-10-14 14:12:13
 *     -                 for the lexer : MySQLLexerLexer
 *
 * Editing it, at least manually, is not wise.
 *
 * C language generator and runtime by Jim Idle, jimi|hereisanat|idle|dotgoeshere|ws.
 *
 *
 * The lexer 
MySQLLexer

has the callable functions (rules) shown below,
 * which will invoke the code for the associated rule in the source grammar
 * assuming that the input stream is pointing to a token/text stream that could begin
 * this rule.
 *
 * For instance if you call the first (topmost) rule in a parser grammar, you will
 * get the results of a full parse, but calling a rule half way through the grammar will
 * allow you to pass part of a full token stream to the parser, such as for syntax checking
 * in editors and so on.
 *
 * The parser entry points are called indirectly (by function pointer to function) via
 * a parser context typedef pMySQLLexer, which is returned from a call to MySQLLexerNew().
 *
 * As this is a generated lexer, it is unlikely you will call it 'manually'. However
 * the methods are provided anyway.
 *
 * The methods in pMySQLLexer are  as follows:
 *
 *  - 
 void
      pMySQLLexer->EQUAL_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ASSIGN_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NULL_SAFE_EQUAL_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GREATER_OR_EQUAL_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GREATER_THAN_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LESS_OR_EQUAL_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LESS_THAN_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NOT_EQUAL_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NOT_EQUAL2_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PLUS_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MINUS_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MULT_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DIV_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MOD_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOGICAL_NOT_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BITWISE_NOT_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SHIFT_LEFT_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SHIFT_RIGHT_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOGICAL_AND_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BITWISE_AND_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BITWISE_XOR_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOGICAL_OR_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BITWISE_OR_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DOT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMMA_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SEMICOLON_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COLON_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OPEN_PAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CLOSE_PAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OPEN_CURLY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CLOSE_CURLY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNDERLINE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->JSON_SEPARATOR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->JSON_UNQUOTED_SEPARATOR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AT_SIGN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AT_AT_SIGN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NULL2_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PARAM_MARKER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BACK_TICK(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SINGLE_QUOTE(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DOUBLE_QUOTE(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ESCAPE_OPERATOR(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DOT_IDENTIFIER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ACCESSIBLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ACCOUNT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ACTION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ADD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ADDDATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AFTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AGAINST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AGGREGATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ALGORITHM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ALL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ALTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ALWAYS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ANALYSE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ANALYZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ANY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ASC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ASCII_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ASENSITIVE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AUTHORS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AUTOEXTEND_SIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AUTO_INCREMENT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AVG_ROW_LENGTH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AVG_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BACKUP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BEFORE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BEGIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BETWEEN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BIGINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BINARY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BINLOG_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BIN_NUM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BIT_AND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BIT_OR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BIT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BIT_XOR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BLOB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BLOCK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BOOLEAN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BOOL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BOTH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BTREE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BYTE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CACHE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CALL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CASCADE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CASCADED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CASE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CAST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CATALOG_NAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHAIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHANGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHANGED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHANNEL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHARSET_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHARACTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHECKSUM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CHECK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CIPHER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CLASS_ORIGIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CLIENT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CLOSE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COALESCE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CODE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COLLATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COLLATION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COLUMNS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COLUMN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COLUMN_NAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COLUMN_FORMAT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMMENT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMMITTED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMMIT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMPACT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMPLETION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMPRESSED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMPRESSION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONCURRENT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONDITION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONNECTION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONSISTENT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONSTRAINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONSTRAINT_CATALOG_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONSTRAINT_NAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONSTRAINT_SCHEMA_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONTAINS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONTEXT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONTINUE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONTRIBUTORS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONVERT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COUNT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CPU_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CREATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CROSS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CUBE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURDATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURRENT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURRENT_DATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURRENT_TIME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURRENT_TIMESTAMP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURRENT_USER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURSOR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURSOR_NAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CURTIME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATABASE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATABASES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATAFILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATA_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATETIME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATE_ADD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATE_ADD_INTERVAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATE_SUB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATE_SUB_INTERVAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DAYOFMONTH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DAY_HOUR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DAY_MICROSECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DAY_MINUTE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DAY_SECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DAY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DEALLOCATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DEC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DECIMAL_NUM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DECIMAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DECLARE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DEFAULT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DEFAULT_AUTH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DEFINER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DELAYED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DELAY_KEY_WRITE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DELETE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DESC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DESCRIBE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DES_KEY_FILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DETERMINISTIC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DIAGNOSTICS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DIRECTORY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DISABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DISCARD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DISK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DISTINCT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DISTINCTROW_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DIV_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DOUBLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DO_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DROP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DUAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DUMPFILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DUPLICATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DYNAMIC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EACH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ELSE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ELSEIF_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ENABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ENCLOSED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->END_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ENDS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->END_OF_INPUT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ENGINES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ENGINE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ENUM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ERROR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ERRORS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ESCAPED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ESCAPE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EVENTS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EVENT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EVERY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXCHANGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXECUTE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXISTS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXIT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXPANSION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXPIRE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXPLAIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXPORT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXTENDED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXTENT_SIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->EXTRACT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FALSE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FAST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FAULTS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FETCH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FIELDS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FILE_BLOCK_SIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FILTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FIRST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FIXED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FLOAT4_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FLOAT8_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FLOAT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FLUSH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FOLLOWS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FORCE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FOREIGN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FOR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FORMAT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FOUND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FRAC_SECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FROM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FULL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FULLTEXT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FUNCTION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GET_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GENERAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GENERATED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GROUP_REPLICATION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GEOMETRYCOLLECTION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GEOMETRY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GET_FORMAT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GLOBAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GRANT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GRANTS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GROUP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->GROUP_CONCAT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HANDLER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HASH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HAVING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HELP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HIGH_PRIORITY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HOST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HOSTS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HOUR_MICROSECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HOUR_MINUTE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HOUR_SECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HOUR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IDENTIFIED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IF_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IGNORE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IGNORE_SERVER_IDS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IMPORT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INDEXES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INDEX_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INFILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INITIAL_SIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INNER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INNODB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INOUT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INSENSITIVE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INSERT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INSERT_METHOD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INSTALL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INTEGER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INTERVAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INTO_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INVOKER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IO_AFTER_GTIDS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IO_BEFORE_GTIDS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IO_THREAD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IO_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IPC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ISOLATION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ISSUER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ITERATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->JOIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->JSON_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->KEYS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->KEY_BLOCK_SIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->KEY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->KILL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LANGUAGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LAST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LEADING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LEAVES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LEAVE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LEFT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LESS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LEVEL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LIKE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LIMIT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LINEAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LINES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LINESTRING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LIST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOAD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOCALTIME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOCALTIMESTAMP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOCAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOCATOR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOCKS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOCK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOGFILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOGS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LONGBLOB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LONGTEXT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LONG_NUM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LONG_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOOP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LOW_PRIORITY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_AUTO_POSITION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_BIND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_CONNECT_RETRY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_DELAY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_HOST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_LOG_FILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_LOG_POS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_PASSWORD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_PORT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_RETRY_COUNT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SERVER_ID_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_CAPATH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_CA_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_CERT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_CIPHER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_CRL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_CRLPATH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_KEY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SSL_VERIFY_SERVER_CERT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_USER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MASTER_HEARTBEAT_PERIOD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MATCH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAX_CONNECTIONS_PER_HOUR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAX_QUERIES_PER_HOUR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAX_ROWS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAX_SIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAX_STATEMENT_TIME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAX_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAX_UPDATES_PER_HOUR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAX_USER_CONNECTIONS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MAXVALUE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MEDIUMBLOB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MEDIUMINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MEDIUMTEXT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MEDIUM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MEMORY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MERGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MESSAGE_TEXT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MICROSECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MID_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MIDDLEINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MIGRATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MINUTE_MICROSECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MINUTE_SECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MINUTE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MIN_ROWS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MODE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MODIFIES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MODIFY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MOD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MONTH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MULTILINESTRING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MULTIPOINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MULTIPOLYGON_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MUTEX_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MYSQL_ERRNO_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NAMES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NATIONAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NATURAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NCHAR_STRING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NCHAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NDB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NDBCLUSTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NEG_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NEVER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NEW_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NEXT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NODEGROUP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NONE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NONBLOCKING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NOT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NOW_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NO_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NO_WAIT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NO_WRITE_TO_BINLOG_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NULL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NUMBER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NUMERIC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NVARCHAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OFFLINE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OFFSET_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OLD_PASSWORD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ON_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ONE_SHOT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ONE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ONLINE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ONLY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OPEN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OPTIMIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OPTIMIZER_COSTS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OPTIONS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OPTION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OPTIONALLY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ORDER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OUTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OUTFILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OUT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->OWNER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PACK_KEYS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PAGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PARSER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PARTIAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PARTITIONING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PARTITIONS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PARTITION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PASSWORD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PHASE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PLUGINS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PLUGIN_DIR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PLUGIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->POINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->POLYGON_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PORT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->POSITION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PRECEDES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PRECISION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PREPARE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PRESERVE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PREV_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PRIMARY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PRIVILEGES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PROCEDURE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PROCESS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PROCESSLIST_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PROFILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PROFILES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PROXY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->PURGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->QUARTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->QUERY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->QUICK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RANGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->READS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->READ_ONLY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->READ_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->READ_WRITE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REBUILD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RECOVER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REDOFILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REDO_BUFFER_SIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REDUNDANT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REFERENCES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REGEXP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RELAY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RELAYLOG_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RELAY_LOG_FILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RELAY_LOG_POS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RELAY_THREAD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RELEASE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RELOAD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REMOVE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RENAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REORGANIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPAIR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPEATABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPEAT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLACE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLICATION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLICATE_DO_DB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLICATE_IGNORE_DB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLICATE_DO_TABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLICATE_IGNORE_TABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLICATE_WILD_DO_TABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLICATE_WILD_IGNORE_TABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REPLICATE_REWRITE_DB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REQUIRE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RESET_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RESIGNAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RESTORE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RESTRICT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RESUME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RETURNED_SQLSTATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RETURNS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RETURN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REVERSE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->REVOKE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RIGHT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RLIKE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ROLLBACK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ROLLUP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ROUTINE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ROWS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ROW_COUNT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ROW_FORMAT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ROW_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->RTREE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SAVEPOINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SCHEDULE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SCHEMA_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SCHEMA_NAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SCHEMAS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SECOND_MICROSECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SECURITY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SELECT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SENSITIVE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SEPARATOR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SERIALIZABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SERIAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SESSION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SERVER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SERVER_OPTIONS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SESSION_USER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SET_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SET_VAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SHARE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SHOW_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SHUTDOWN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SIGNAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SIGNED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SIMPLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SLAVE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SLOW_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SMALLINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SNAPSHOT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SOME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SOCKET_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SONAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SOUNDS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SOURCE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SPATIAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SPECIFIC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQLEXCEPTION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQLSTATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQLWARNING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_AFTER_GTIDS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_AFTER_MTS_GAPS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_BEFORE_GTIDS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_BIG_RESULT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_BUFFER_RESULT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_CACHE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_CALC_FOUND_ROWS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_NO_CACHE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_SMALL_RESULT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_THREAD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SSL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STACKED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STARTING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STARTS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->START_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STATS_AUTO_RECALC_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STATS_PERSISTENT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STATS_SAMPLE_PAGES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STATUS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STDDEV_SAMP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STDDEV_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STDDEV_POP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STOP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STORAGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STORED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STRAIGHT_JOIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->STRING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUBCLASS_ORIGIN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUBDATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUBJECT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUBPARTITIONS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUBPARTITION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUBSTR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUBSTRING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUPER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SUSPEND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SWAPS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SWITCHES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SYSDATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SYSTEM_USER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TABLES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TABLESPACE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TABLE_REF_PRIORITY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TABLE_CHECKSUM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TABLE_NAME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TEMPORARY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TEMPTABLE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TERMINATED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TEXT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->THAN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->THEN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TIMESTAMP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TIMESTAMP_ADD_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TIMESTAMP_DIFF_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TIME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TINYBLOB_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TINYINT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TINYTEXT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TO_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TRAILING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TRANSACTION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TRIGGERS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TRIGGER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TRIM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TRUE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TRUNCATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TYPES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->TYPE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UDF_RETURNS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNCOMMITTED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNDEFINED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNDOFILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNDO_BUFFER_SIZE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNDO_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNICODE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNINSTALL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNIQUE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNKNOWN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNLOCK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNSIGNED_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNTIL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UPDATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UPGRADE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->USAGE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->USER_RESOURCES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->USER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->USE_FRM_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->USE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->USING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UTC_DATE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UTC_TIMESTAMP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UTC_TIME_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VALIDATION_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VALUES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VALUE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VARBINARY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VARCHAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VARCHARACTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VARIABLES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VARIANCE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VARYING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VAR_POP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VAR_SAMP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VIEW_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VIRTUAL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WAIT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WARNINGS_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WEEK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WEIGHT_STRING_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WHEN_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WHERE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WHILE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WITH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WITH_CUBE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WITH_ROLLUP_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WITHOUT_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WORK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WRAPPER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WRITE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->X509_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->XA_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->XID_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->XML_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->XOR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->YEAR_MONTH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->YEAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ZEROFILL_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INT1_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INT2_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INT3_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INT4_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INT8_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_FRAC_SECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_SECOND_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_MINUTE_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_HOUR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_DAY_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_WEEK_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_MONTH_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_QUARTER_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SQL_TSI_YEAR_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->WHITESPACE(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INVALID_INPUT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HEX_NUMBER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BIN_NUMBER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->UNDERSCORE_CHARSET(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->IDENTIFIER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NCHAR_TEXT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NUMBER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DECIMAL_NUMBER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->FLOAT_NUMBER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BACK_TICK_QUOTED_ID(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DOUBLE_QUOTED_TEXT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SINGLE_QUOTED_TEXT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->COMMENT_RULE(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->BLOCK_COMMENT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VERSION_COMMENT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VERSION_COMMENT_TAIL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->MULTILINE_COMMENT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VERSION_COMMENT_END(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->POUND_COMMENT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DASHDASH_COMMENT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DOUBLE_DASH(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LINEBREAK(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DIGIT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->DIGITS(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->HEXDIGIT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->SIMPLE_IDENTIFIER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ML_COMMENT_HEAD(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ML_COMMENT_END(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->VERSION_COMMENT_INTRODUCER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LETTER_WHEN_UNQUOTED(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LETTER_WHEN_UNQUOTED_NO_DIGIT(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->NOT2_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->CONCAT_PIPES_SYMBOL(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->AT_TEXT_SUFFIX(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->INT_NUMBER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->LONG_NUMBER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->ULONGLONG_NUMBER(pMySQLLexer)
 *  - 
 void
      pMySQLLexer->Tokens(pMySQLLexer)
 * 
 *
 * The return type for any particular rule is of course determined by the source
 * grammar file.
 */
// [The "BSD license"]
// Copyright (c) 2005-2009 Jim Idle, Temporal Wave LLC
// http://www.temporal-wave.com
// http://www.linkedin.com/in/jimidle
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
// 3. The name of the author may not be used to endorse or promote products
//    derived from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
// NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef	_MySQLLexer_H
#define _MySQLLexer_H
/* =============================================================================
 * Standard antlr3 C runtime definitions
 */
#include    <antlr3.h>

/* End of standard antlr 3 runtime definitions
 * =============================================================================
 */


// This structure carries important values that are needed to make the lexer + parser work properly, as they
// provide context information. The code which creates parser and lexer must set a reference to such a structure
// initialized to the proper values in the shared lexer/parser state userp member.
typedef struct {
  int versionMatched;    // True if a given version number is less or equal compare to that of the server.
  int inVersionComment;  // True if we are in a version comment (/*!12345 ... */).
  long version;
  unsigned sqlMode;      // A collection of flags indicating which of relevant SQL modes are active.
  void *payload;         // Since we use the usercp for this struct we need another way to pass around other arbitrary data.
} RecognitionContext;

// SQL modes that control parsing behavior.
#define SQL_MODE_ANSI_QUOTES            1
#define SQL_MODE_HIGH_NOT_PRECEDENCE    2
#define SQL_MODE_PIPES_AS_CONCAT        4
#define SQL_MODE_IGNORE_SPACE           8
#define SQL_MODE_NO_BACKSLASH_ESCAPES  16

// 2 vars stored in state pointer (otherwise we would have to create global vars).
#define VERSION_MATCHED ((RecognitionContext*)RECOGNIZER->state->userp)->versionMatched
#define IN_VERSION_COMMENT ((RecognitionContext*)RECOGNIZER->state->userp)->inVersionComment

#define PAYLOAD ((RecognitionContext*)RECOGNIZER->state->userp)->payload
#define SERVER_VERSION ((RecognitionContext*)RECOGNIZER->state->userp)->version
#define TYPE_FROM_VERSION(version, type) (SERVER_VERSION >= version ? type : IDENTIFIER)
#define DEPRECATED_TYPE_FROM_VERSION(version, type) (SERVER_VERSION < version ? type : IDENTIFIER)
#define TYPE_IN_VERSION_RANGE(small_version, large_version, type) ((SERVER_VERSION >= small_version && SERVER_VERSION < large_version) ? type : IDENTIFIER)
#define SQL_MODE_ACTIVE(mode) (((RecognitionContext*)RECOGNIZER->state->userp)->sqlMode & mode) != 0



#ifdef __cplusplus
extern "C" {
#endif

// Forward declare the context typedef so that we can use it before it is
// properly defined. Delegators and delegates (from import statements) are
// interdependent and their context structures contain pointers to each other
// C only allows such things to be declared if you pre-declare the typedef.
//
typedef struct MySQLLexer_Ctx_struct MySQLLexer, * pMySQLLexer;




#define ANTLR3_HUGE
#ifndef _WIN32
// Usually suppressing such warnings is wrong, but here we got to do with generated code,
// so it's ok for this specific case.
#pragma GCC diagnostic ignored "-Wunused-variable"
#pragma GCC diagnostic ignored "-Wparentheses"
#ifdef __clang__
// Comparison of unsigned expression >= 0 is always true.
#pragma GCC diagnostic ignored "-Wtautological-compare"
#else
#if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 6 )
#pragma GCC diagnostic ignored "-Wtype-limits"
#endif
#endif
#else
#pragma warning(disable:4296) // Condition is always true.
#endif



#ifdef	ANTLR3_WINDOWS
// Disable: Unreferenced parameter,							- Rules with parameters that are not used
//          constant conditional,							- ANTLR realizes that a prediction is always true (synpred usually)
//          initialized but unused variable					- tree rewrite variables declared but not needed
//          Unreferenced local variable						- lexer rule declares but does not always use _type
//          potentially unitialized variable used			- retval always returned from a rule
//			unreferenced local function has been removed	- susually getTokenNames or freeScope, they can go without warnigns
//
// These are only really displayed at warning level /W4 but that is the code ideal I am aiming at
// and the codegen must generate some of these warnings by necessity, apart from 4100, which is
// usually generated when a parser rule is given a parameter that it does not use. Mostly though
// this is a matter of orthogonality hence I disable that one.
//
#pragma warning( disable : 4100 )
#pragma warning( disable : 4101 )
#pragma warning( disable : 4127 )
#pragma warning( disable : 4189 )
#pragma warning( disable : 4505 )
#pragma warning( disable : 4701 )
#endif

/* ========================
 * BACKTRACKING IS ENABLED
 * ========================
 */


/** Context tracking structure for 
MySQLLexer

 */
struct MySQLLexer_Ctx_struct
{
    /** Built in ANTLR3 context tracker contains all the generic elements
     *  required for context tracking.
     */
    pANTLR3_LEXER    pLexer;

     void
     (*mEQUAL_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mASSIGN_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNULL_SAFE_EQUAL_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGREATER_OR_EQUAL_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGREATER_THAN_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLESS_OR_EQUAL_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLESS_THAN_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNOT_EQUAL_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNOT_EQUAL2_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPLUS_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMINUS_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMULT_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDIV_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMOD_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOGICAL_NOT_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBITWISE_NOT_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSHIFT_LEFT_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSHIFT_RIGHT_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOGICAL_AND_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBITWISE_AND_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBITWISE_XOR_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOGICAL_OR_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBITWISE_OR_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDOT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMMA_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSEMICOLON_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOLON_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOPEN_PAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCLOSE_PAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOPEN_CURLY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCLOSE_CURLY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNDERLINE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mJSON_SEPARATOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mJSON_UNQUOTED_SEPARATOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAT_SIGN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAT_AT_SIGN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNULL2_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPARAM_MARKER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBACK_TICK)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSINGLE_QUOTE)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDOUBLE_QUOTE)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mESCAPE_OPERATOR)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDOT_IDENTIFIER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mACCESSIBLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mACCOUNT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mACTION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mADD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mADDDATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAFTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAGAINST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAGGREGATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mALGORITHM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mALL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mALTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mALWAYS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mANALYSE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mANALYZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mANY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mASC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mASCII_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mASENSITIVE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAUTHORS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAUTOEXTEND_SIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAUTO_INCREMENT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAVG_ROW_LENGTH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAVG_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBACKUP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBEFORE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBEGIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBETWEEN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBIGINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBINARY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBINLOG_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBIN_NUM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBIT_AND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBIT_OR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBIT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBIT_XOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBLOB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBLOCK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBOOLEAN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBOOL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBOTH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBTREE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBYTE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCACHE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCALL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCASCADE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCASCADED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCASE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCAST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCATALOG_NAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHAIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHANGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHANGED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHANNEL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHARSET_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHARACTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHECKSUM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCHECK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCIPHER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCLASS_ORIGIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCLIENT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCLOSE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOALESCE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCODE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOLLATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOLLATION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOLUMNS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOLUMN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOLUMN_NAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOLUMN_FORMAT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMMENT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMMITTED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMMIT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMPACT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMPLETION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMPRESSED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMPRESSION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONCURRENT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONDITION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONNECTION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONSISTENT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONSTRAINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONSTRAINT_CATALOG_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONSTRAINT_NAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONSTRAINT_SCHEMA_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONTAINS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONTEXT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONTINUE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONTRIBUTORS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONVERT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOUNT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCPU_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCREATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCROSS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCUBE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURDATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURRENT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURRENT_DATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURRENT_TIME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURRENT_TIMESTAMP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURRENT_USER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURSOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURSOR_NAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCURTIME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATABASE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATABASES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATAFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATA_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATETIME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATE_ADD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATE_ADD_INTERVAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATE_SUB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATE_SUB_INTERVAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDAYOFMONTH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDAY_HOUR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDAY_MICROSECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDAY_MINUTE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDAY_SECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDAY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDEALLOCATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDEC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDECIMAL_NUM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDECIMAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDECLARE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDEFAULT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDEFAULT_AUTH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDEFINER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDELAYED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDELAY_KEY_WRITE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDELETE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDESC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDESCRIBE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDES_KEY_FILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDETERMINISTIC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDIAGNOSTICS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDIRECTORY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDISABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDISCARD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDISK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDISTINCT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDISTINCTROW_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDIV_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDOUBLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDO_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDROP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDUAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDUMPFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDUPLICATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDYNAMIC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEACH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mELSE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mELSEIF_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mENABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mENCLOSED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mENDS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEND_OF_INPUT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mENGINES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mENGINE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mENUM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mERROR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mERRORS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mESCAPED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mESCAPE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEVENTS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEVENT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEVERY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXCHANGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXECUTE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXISTS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXIT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXPANSION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXPIRE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXPLAIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXPORT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXTENDED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXTENT_SIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mEXTRACT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFALSE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFAST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFAULTS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFETCH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFIELDS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFILE_BLOCK_SIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFILTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFIRST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFIXED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFLOAT4_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFLOAT8_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFLOAT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFLUSH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFOLLOWS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFORCE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFOREIGN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFORMAT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFOUND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFRAC_SECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFROM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFULL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFULLTEXT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFUNCTION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGET_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGENERAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGENERATED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGROUP_REPLICATION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGEOMETRYCOLLECTION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGEOMETRY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGET_FORMAT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGLOBAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGRANT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGRANTS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGROUP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mGROUP_CONCAT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHANDLER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHASH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHAVING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHELP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHIGH_PRIORITY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHOST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHOSTS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHOUR_MICROSECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHOUR_MINUTE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHOUR_SECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHOUR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIDENTIFIED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIF_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIGNORE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIGNORE_SERVER_IDS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIMPORT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINDEXES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINDEX_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINITIAL_SIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINNER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINNODB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINOUT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINSENSITIVE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINSERT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINSERT_METHOD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINSTALL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINTEGER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINTERVAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINTO_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINVOKER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIO_AFTER_GTIDS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIO_BEFORE_GTIDS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIO_THREAD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIO_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIPC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mISOLATION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mISSUER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mITERATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mJOIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mJSON_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mKEYS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mKEY_BLOCK_SIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mKEY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mKILL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLANGUAGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLAST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLEADING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLEAVES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLEAVE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLEFT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLESS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLEVEL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLIKE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLIMIT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLINEAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLINES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLINESTRING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLIST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOAD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOCALTIME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOCALTIMESTAMP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOCAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOCATOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOCKS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOCK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOGFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOGS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLONGBLOB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLONGTEXT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLONG_NUM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLONG_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOOP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLOW_PRIORITY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_AUTO_POSITION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_BIND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_CONNECT_RETRY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_DELAY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_HOST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_LOG_FILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_LOG_POS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_PASSWORD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_PORT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_RETRY_COUNT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SERVER_ID_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_CAPATH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_CA_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_CERT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_CIPHER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_CRL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_CRLPATH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_KEY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SSL_VERIFY_SERVER_CERT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_USER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMASTER_HEARTBEAT_PERIOD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMATCH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAX_CONNECTIONS_PER_HOUR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAX_QUERIES_PER_HOUR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAX_ROWS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAX_SIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAX_STATEMENT_TIME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAX_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAX_UPDATES_PER_HOUR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAX_USER_CONNECTIONS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMAXVALUE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMEDIUMBLOB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMEDIUMINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMEDIUMTEXT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMEDIUM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMEMORY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMERGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMESSAGE_TEXT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMICROSECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMID_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMIDDLEINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMIGRATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMINUTE_MICROSECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMINUTE_SECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMINUTE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMIN_ROWS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMODE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMODIFIES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMODIFY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMOD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMONTH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMULTILINESTRING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMULTIPOINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMULTIPOLYGON_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMUTEX_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMYSQL_ERRNO_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNAMES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNATIONAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNATURAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNCHAR_STRING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNCHAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNDB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNDBCLUSTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNEG_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNEVER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNEW_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNEXT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNODEGROUP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNONE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNONBLOCKING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNOT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNOW_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNO_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNO_WAIT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNO_WRITE_TO_BINLOG_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNULL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNUMBER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNUMERIC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNVARCHAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOFFLINE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOFFSET_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOLD_PASSWORD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mON_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mONE_SHOT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mONE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mONLINE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mONLY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOPEN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOPTIMIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOPTIMIZER_COSTS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOPTIONS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOPTION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOPTIONALLY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mORDER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOUTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOUTFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOUT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mOWNER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPACK_KEYS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPAGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPARSER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPARTIAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPARTITIONING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPARTITIONS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPARTITION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPASSWORD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPHASE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPLUGINS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPLUGIN_DIR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPLUGIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPOINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPOLYGON_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPORT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPOSITION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPRECEDES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPRECISION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPREPARE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPRESERVE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPREV_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPRIMARY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPRIVILEGES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPROCEDURE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPROCESS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPROCESSLIST_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPROFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPROFILES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPROXY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPURGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mQUARTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mQUERY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mQUICK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRANGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREADS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREAD_ONLY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREAD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREAD_WRITE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREBUILD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRECOVER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREDOFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREDO_BUFFER_SIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREDUNDANT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREFERENCES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREGEXP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRELAY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRELAYLOG_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRELAY_LOG_FILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRELAY_LOG_POS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRELAY_THREAD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRELEASE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRELOAD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREMOVE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRENAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREORGANIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPAIR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPEATABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPEAT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLACE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLICATION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLICATE_DO_DB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLICATE_IGNORE_DB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLICATE_DO_TABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLICATE_IGNORE_TABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLICATE_WILD_DO_TABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLICATE_WILD_IGNORE_TABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREPLICATE_REWRITE_DB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREQUIRE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRESET_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRESIGNAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRESTORE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRESTRICT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRESUME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRETURNED_SQLSTATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRETURNS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRETURN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREVERSE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mREVOKE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRIGHT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRLIKE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mROLLBACK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mROLLUP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mROUTINE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mROWS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mROW_COUNT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mROW_FORMAT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mROW_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mRTREE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSAVEPOINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSCHEDULE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSCHEMA_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSCHEMA_NAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSCHEMAS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSECOND_MICROSECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSECURITY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSELECT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSENSITIVE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSEPARATOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSERIALIZABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSERIAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSESSION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSERVER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSERVER_OPTIONS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSESSION_USER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSET_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSET_VAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSHARE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSHOW_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSHUTDOWN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSIGNAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSIGNED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSIMPLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSLAVE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSLOW_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSMALLINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSNAPSHOT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSOME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSOCKET_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSONAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSOUNDS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSOURCE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSPATIAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSPECIFIC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQLEXCEPTION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQLSTATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQLWARNING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_AFTER_GTIDS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_AFTER_MTS_GAPS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_BEFORE_GTIDS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_BIG_RESULT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_BUFFER_RESULT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_CACHE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_CALC_FOUND_ROWS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_NO_CACHE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_SMALL_RESULT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_THREAD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSSL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTACKED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTARTING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTARTS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTART_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTATS_AUTO_RECALC_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTATS_PERSISTENT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTATS_SAMPLE_PAGES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTATUS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTDDEV_SAMP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTDDEV_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTDDEV_POP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTOP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTORAGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTORED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTRAIGHT_JOIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSTRING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUBCLASS_ORIGIN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUBDATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUBJECT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUBPARTITIONS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUBPARTITION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUBSTR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUBSTRING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUPER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSUSPEND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSWAPS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSWITCHES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSYSDATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSYSTEM_USER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTABLES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTABLESPACE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTABLE_REF_PRIORITY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTABLE_CHECKSUM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTABLE_NAME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTEMPORARY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTEMPTABLE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTERMINATED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTEXT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTHAN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTHEN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTIMESTAMP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTIMESTAMP_ADD_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTIMESTAMP_DIFF_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTIME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTINYBLOB_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTINYINT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTINYTEXT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTO_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTRAILING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTRANSACTION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTRIGGERS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTRIGGER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTRIM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTRUE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTRUNCATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTYPES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTYPE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUDF_RETURNS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNCOMMITTED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNDEFINED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNDOFILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNDO_BUFFER_SIZE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNDO_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNICODE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNINSTALL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNIQUE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNKNOWN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNLOCK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNSIGNED_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNTIL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUPDATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUPGRADE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUSAGE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUSER_RESOURCES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUSER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUSE_FRM_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUSE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUSING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUTC_DATE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUTC_TIMESTAMP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUTC_TIME_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVALIDATION_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVALUES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVALUE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVARBINARY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVARCHAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVARCHARACTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVARIABLES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVARIANCE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVARYING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVAR_POP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVAR_SAMP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVIEW_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVIRTUAL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWAIT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWARNINGS_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWEEK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWEIGHT_STRING_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWHEN_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWHERE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWHILE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWITH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWITH_CUBE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWITH_ROLLUP_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWITHOUT_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWORK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWRAPPER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWRITE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mX509_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mXA_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mXID_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mXML_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mXOR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mYEAR_MONTH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mYEAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mZEROFILL_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINT1_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINT2_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINT3_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINT4_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINT8_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_FRAC_SECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_SECOND_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_MINUTE_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_HOUR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_DAY_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_WEEK_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_MONTH_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_QUARTER_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSQL_TSI_YEAR_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mWHITESPACE)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINVALID_INPUT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHEX_NUMBER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBIN_NUMBER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mUNDERSCORE_CHARSET)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mIDENTIFIER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNCHAR_TEXT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNUMBER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDECIMAL_NUMBER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mFLOAT_NUMBER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBACK_TICK_QUOTED_ID)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDOUBLE_QUOTED_TEXT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSINGLE_QUOTED_TEXT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCOMMENT_RULE)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mBLOCK_COMMENT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVERSION_COMMENT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVERSION_COMMENT_TAIL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mMULTILINE_COMMENT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVERSION_COMMENT_END)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mPOUND_COMMENT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDASHDASH_COMMENT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDOUBLE_DASH)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLINEBREAK)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDIGIT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mDIGITS)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mHEXDIGIT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mSIMPLE_IDENTIFIER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mML_COMMENT_HEAD)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mML_COMMENT_END)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mVERSION_COMMENT_INTRODUCER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLETTER_WHEN_UNQUOTED)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLETTER_WHEN_UNQUOTED_NO_DIGIT)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mNOT2_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mCONCAT_PIPES_SYMBOL)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mAT_TEXT_SUFFIX)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mINT_NUMBER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mLONG_NUMBER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mULONGLONG_NUMBER)	(struct MySQLLexer_Ctx_struct * ctx);

     void
     (*mTokens)	(struct MySQLLexer_Ctx_struct * ctx);

    const char * (*getGrammarFileName)();
    void            (*reset)  (struct MySQLLexer_Ctx_struct * ctx);
    void	    (*free)   (struct MySQLLexer_Ctx_struct * ctx);

    // A pointer to the original nextToken function.
    pANTLR3_COMMON_TOKEN (*originalNextToken)(pANTLR3_TOKEN_SOURCE tokenSource);

    // Contains ANTLR3_COMMON_TOKEN instances.
    pANTLR3_VECTOR pendingTokens;

};

// Function protoypes for the constructor functions that external translation units
// such as delegators and delegates may wish to call.
//
ANTLR3_API pMySQLLexer MySQLLexerNew         (
pANTLR3_INPUT_STREAM
 instream);
ANTLR3_API pMySQLLexer MySQLLexerNewSSD      (
pANTLR3_INPUT_STREAM
 instream, pANTLR3_RECOGNIZER_SHARED_STATE state);

/** Symbolic definitions of all the tokens that the 
lexer
 will work with.
 * \{
 *
 * Antlr will define EOF, but we can't use that as it it is too common in
 * in C header files and that would be confusing. There is no way to filter this out at the moment
 * so we just undef it here for now. That isn't the value we get back from C recognizers
 * anyway. We are looking for ANTLR3_TOKEN_EOF.
 */
#ifdef	EOF
#undef	EOF
#endif
#ifdef	Tokens
#undef	Tokens
#endif
#define EOF      -1
#define ACCOUNT_SYMBOL      4
#define ASCII_SYMBOL      5
#define ALWAYS_SYMBOL      6
#define BACKUP_SYMBOL      7
#define BEGIN_SYMBOL      8
#define BYTE_SYMBOL      9
#define CACHE_SYMBOL      10
#define CHARSET_SYMBOL      11
#define CHECKSUM_SYMBOL      12
#define CLOSE_SYMBOL      13
#define COMMENT_SYMBOL      14
#define COMMIT_SYMBOL      15
#define CONTAINS_SYMBOL      16
#define DEALLOCATE_SYMBOL      17
#define DO_SYMBOL      18
#define END_SYMBOL      19
#define EXECUTE_SYMBOL      20
#define FLUSH_SYMBOL      21
#define FOLLOWS_SYMBOL      22
#define FORMAT_SYMBOL      23
#define GROUP_REPLICATION_SYMBOL      24
#define HANDLER_SYMBOL      25
#define HELP_SYMBOL      26
#define HOST_SYMBOL      27
#define INSTALL_SYMBOL      28
#define LANGUAGE_SYMBOL      29
#define NO_SYMBOL      30
#define OPEN_SYMBOL      31
#define OPTIONS_SYMBOL      32
#define OWNER_SYMBOL      33
#define PARSER_SYMBOL      34
#define PARTITION_SYMBOL      35
#define PORT_SYMBOL      36
#define PRECEDES_SYMBOL      37
#define PREPARE_SYMBOL      38
#define REMOVE_SYMBOL      39
#define REPAIR_SYMBOL      40
#define RESET_SYMBOL      41
#define RESTORE_SYMBOL      42
#define ROLLBACK_SYMBOL      43
#define SAVEPOINT_SYMBOL      44
#define SECURITY_SYMBOL      45
#define SERVER_SYMBOL      46
#define SIGNED_SYMBOL      47
#define SLAVE_SYMBOL      48
#define SOCKET_SYMBOL      49
#define SONAME_SYMBOL      50
#define START_SYMBOL      51
#define STOP_SYMBOL      52
#define TRUNCATE_SYMBOL      53
#define UNICODE_SYMBOL      54
#define UNINSTALL_SYMBOL      55
#define UPGRADE_SYMBOL      56
#define WRAPPER_SYMBOL      57
#define XA_SYMBOL      58
#define ACTION_SYMBOL      59
#define ADDDATE_SYMBOL      60
#define AFTER_SYMBOL      61
#define AGAINST_SYMBOL      62
#define AGGREGATE_SYMBOL      63
#define ALGORITHM_SYMBOL      64
#define ANALYZE_SYMBOL      65
#define ANY_SYMBOL      66
#define AT_SYMBOL      67
#define AUTHORS_SYMBOL      68
#define AUTO_INCREMENT_SYMBOL      69
#define AUTOEXTEND_SIZE_SYMBOL      70
#define AVG_ROW_LENGTH_SYMBOL      71
#define AVG_SYMBOL      72
#define BINLOG_SYMBOL      73
#define BIT_SYMBOL      74
#define BLOCK_SYMBOL      75
#define BOOL_SYMBOL      76
#define BOOLEAN_SYMBOL      77
#define BTREE_SYMBOL      78
#define CASCADED_SYMBOL      79
#define CATALOG_NAME_SYMBOL      80
#define CHAIN_SYMBOL      81
#define CHANGED_SYMBOL      82
#define CHANNEL_SYMBOL      83
#define CIPHER_SYMBOL      84
#define CLIENT_SYMBOL      85
#define CLASS_ORIGIN_SYMBOL      86
#define COALESCE_SYMBOL      87
#define CODE_SYMBOL      88
#define COLLATION_SYMBOL      89
#define COLUMN_NAME_SYMBOL      90
#define COLUMN_FORMAT_SYMBOL      91
#define COLUMNS_SYMBOL      92
#define COMMITTED_SYMBOL      93
#define COMPACT_SYMBOL      94
#define COMPLETION_SYMBOL      95
#define COMPRESSED_SYMBOL      96
#define COMPRESSION_SYMBOL      97
#define CONCURRENT_SYMBOL      98
#define CONNECTION_SYMBOL      99
#define CONSISTENT_SYMBOL      100
#define CONSTRAINT_CATALOG_SYMBOL      101
#define CONSTRAINT_SCHEMA_SYMBOL      102
#define CONSTRAINT_NAME_SYMBOL      103
#define CONTEXT_SYMBOL      104
#define CONTRIBUTORS_SYMBOL      105
#define CPU_SYMBOL      106
#define CUBE_SYMBOL      107
#define CURRENT_SYMBOL      108
#define CURSOR_NAME_SYMBOL      109
#define DATA_SYMBOL      110
#define DATAFILE_SYMBOL      111
#define DATETIME_SYMBOL      112
#define DATE_SYMBOL      113
#define DAY_SYMBOL      114
#define DEFAULT_AUTH_SYMBOL      115
#define DEFINER_SYMBOL      116
#define DELAY_KEY_WRITE_SYMBOL      117
#define DES_KEY_FILE_SYMBOL      118
#define DIAGNOSTICS_SYMBOL      119
#define DIRECTORY_SYMBOL      120
#define DISABLE_SYMBOL      121
#define DISCARD_SYMBOL      122
#define DISK_SYMBOL      123
#define DUMPFILE_SYMBOL      124
#define DUPLICATE_SYMBOL      125
#define DYNAMIC_SYMBOL      126
#define ENDS_SYMBOL      127
#define ENUM_SYMBOL      128
#define ENGINE_SYMBOL      129
#define ENGINES_SYMBOL      130
#define ERROR_SYMBOL      131
#define ERRORS_SYMBOL      132
#define ESCAPE_SYMBOL      133
#define EVENT_SYMBOL      134
#define EVENTS_SYMBOL      135
#define EVERY_SYMBOL      136
#define EXPANSION_SYMBOL      137
#define EXPORT_SYMBOL      138
#define EXTENDED_SYMBOL      139
#define EXTENT_SIZE_SYMBOL      140
#define FAULTS_SYMBOL      141
#define FAST_SYMBOL      142
#define FOUND_SYMBOL      143
#define ENABLE_SYMBOL      144
#define FULL_SYMBOL      145
#define FILE_SYMBOL      146
#define FILE_BLOCK_SIZE_SYMBOL      147
#define FILTER_SYMBOL      148
#define FIRST_SYMBOL      149
#define FIXED_SYMBOL      150
#define GENERAL_SYMBOL      151
#define GEOMETRY_SYMBOL      152
#define GEOMETRYCOLLECTION_SYMBOL      153
#define GET_FORMAT_SYMBOL      154
#define GRANTS_SYMBOL      155
#define GLOBAL_SYMBOL      156
#define HASH_SYMBOL      157
#define HOSTS_SYMBOL      158
#define HOUR_SYMBOL      159
#define IDENTIFIED_SYMBOL      160
#define IGNORE_SERVER_IDS_SYMBOL      161
#define INVOKER_SYMBOL      162
#define IMPORT_SYMBOL      163
#define INDEXES_SYMBOL      164
#define INITIAL_SIZE_SYMBOL      165
#define INNODB_SYMBOL      166
#define IO_SYMBOL      167
#define IPC_SYMBOL      168
#define ISOLATION_SYMBOL      169
#define ISSUER_SYMBOL      170
#define INSERT_METHOD_SYMBOL      171
#define JSON_SYMBOL      172
#define KEY_BLOCK_SIZE_SYMBOL      173
#define LAST_SYMBOL      174
#define LEAVES_SYMBOL      175
#define LESS_SYMBOL      176
#define LEVEL_SYMBOL      177
#define LINESTRING_SYMBOL      178
#define LIST_SYMBOL      179
#define LOCAL_SYMBOL      180
#define LOCKS_SYMBOL      181
#define LOGFILE_SYMBOL      182
#define LOGS_SYMBOL      183
#define MAX_ROWS_SYMBOL      184
#define MASTER_SYMBOL      185
#define MASTER_HEARTBEAT_PERIOD_SYMBOL      186
#define MASTER_HOST_SYMBOL      187
#define MASTER_PORT_SYMBOL      188
#define MASTER_LOG_FILE_SYMBOL      189
#define MASTER_LOG_POS_SYMBOL      190
#define MASTER_USER_SYMBOL      191
#define MASTER_PASSWORD_SYMBOL      192
#define MASTER_SERVER_ID_SYMBOL      193
#define MASTER_CONNECT_RETRY_SYMBOL      194
#define MASTER_RETRY_COUNT_SYMBOL      195
#define MASTER_DELAY_SYMBOL      196
#define MASTER_SSL_SYMBOL      197
#define MASTER_SSL_CA_SYMBOL      198
#define MASTER_SSL_CAPATH_SYMBOL      199
#define MASTER_SSL_CERT_SYMBOL      200
#define MASTER_SSL_CIPHER_SYMBOL      201
#define MASTER_SSL_CRL_SYMBOL      202
#define MASTER_SSL_CRLPATH_SYMBOL      203
#define MASTER_SSL_KEY_SYMBOL      204
#define MASTER_AUTO_POSITION_SYMBOL      205
#define MAX_CONNECTIONS_PER_HOUR_SYMBOL      206
#define MAX_QUERIES_PER_HOUR_SYMBOL      207
#define MAX_STATEMENT_TIME_SYMBOL      208
#define MAX_SIZE_SYMBOL      209
#define MAX_UPDATES_PER_HOUR_SYMBOL      210
#define MAX_USER_CONNECTIONS_SYMBOL      211
#define MEDIUM_SYMBOL      212
#define MEMORY_SYMBOL      213
#define MERGE_SYMBOL      214
#define MESSAGE_TEXT_SYMBOL      215
#define MICROSECOND_SYMBOL      216
#define MIGRATE_SYMBOL      217
#define MINUTE_SYMBOL      218
#define MIN_ROWS_SYMBOL      219
#define MODIFY_SYMBOL      220
#define MODE_SYMBOL      221
#define MONTH_SYMBOL      222
#define MULTILINESTRING_SYMBOL      223
#define MULTIPOINT_SYMBOL      224
#define MULTIPOLYGON_SYMBOL      225
#define MUTEX_SYMBOL      226
#define MYSQL_ERRNO_SYMBOL      227
#define NAME_SYMBOL      228
#define NAMES_SYMBOL      229
#define NATIONAL_SYMBOL      230
#define NCHAR_SYMBOL      231
#define NDBCLUSTER_SYMBOL      232
#define NEVER_SYMBOL      233
#define NEXT_SYMBOL      234
#define NEW_SYMBOL      235
#define NO_WAIT_SYMBOL      236
#define NODEGROUP_SYMBOL      237
#define NONE_SYMBOL      238
#define NUMBER_SYMBOL      239
#define NVARCHAR_SYMBOL      240
#define OFFSET_SYMBOL      241
#define OLD_PASSWORD_SYMBOL      242
#define ONE_SHOT_SYMBOL      243
#define ONE_SYMBOL      244
#define PACK_KEYS_SYMBOL      245
#define PAGE_SYMBOL      246
#define PARTIAL_SYMBOL      247
#define PARTITIONING_SYMBOL      248
#define PARTITIONS_SYMBOL      249
#define PASSWORD_SYMBOL      250
#define PHASE_SYMBOL      251
#define PLUGIN_DIR_SYMBOL      252
#define PLUGIN_SYMBOL      253
#define PLUGINS_SYMBOL      254
#define POINT_SYMBOL      255
#define POLYGON_SYMBOL      256
#define PRESERVE_SYMBOL      257
#define PREV_SYMBOL      258
#define PRIVILEGES_SYMBOL      259
#define PROCESS_SYMBOL      260
#define PROCESSLIST_SYMBOL      261
#define PROFILE_SYMBOL      262
#define PROFILES_SYMBOL      263
#define PROXY_SYMBOL      264
#define QUARTER_SYMBOL      265
#define QUERY_SYMBOL      266
#define QUICK_SYMBOL      267
#define READ_ONLY_SYMBOL      268
#define REBUILD_SYMBOL      269
#define RECOVER_SYMBOL      270
#define REDO_BUFFER_SIZE_SYMBOL      271
#define REDOFILE_SYMBOL      272
#define REDUNDANT_SYMBOL      273
#define RELAY_SYMBOL      274
#define RELAYLOG_SYMBOL      275
#define RELAY_LOG_FILE_SYMBOL      276
#define RELAY_LOG_POS_SYMBOL      277
#define RELAY_THREAD_SYMBOL      278
#define RELOAD_SYMBOL      279
#define REORGANIZE_SYMBOL      280
#define REPEATABLE_SYMBOL      281
#define REPLICATION_SYMBOL      282
#define REPLICATE_DO_DB_SYMBOL      283
#define REPLICATE_IGNORE_DB_SYMBOL      284
#define REPLICATE_DO_TABLE_SYMBOL      285
#define REPLICATE_IGNORE_TABLE_SYMBOL      286
#define REPLICATE_WILD_DO_TABLE_SYMBOL      287
#define REPLICATE_WILD_IGNORE_TABLE_SYMBOL      288
#define REPLICATE_REWRITE_DB_SYMBOL      289
#define RESUME_SYMBOL      290
#define RETURNED_SQLSTATE_SYMBOL      291
#define RETURNS_SYMBOL      292
#define REVERSE_SYMBOL      293
#define ROLLUP_SYMBOL      294
#define ROUTINE_SYMBOL      295
#define ROWS_SYMBOL      296
#define ROW_COUNT_SYMBOL      297
#define ROW_FORMAT_SYMBOL      298
#define ROW_SYMBOL      299
#define RTREE_SYMBOL      300
#define SCHEDULE_SYMBOL      301
#define SCHEMA_NAME_SYMBOL      302
#define SECOND_SYMBOL      303
#define SERIAL_SYMBOL      304
#define SERIALIZABLE_SYMBOL      305
#define SESSION_SYMBOL      306
#define SIMPLE_SYMBOL      307
#define SHARE_SYMBOL      308
#define SHUTDOWN_SYMBOL      309
#define SLOW_SYMBOL      310
#define SNAPSHOT_SYMBOL      311
#define SOUNDS_SYMBOL      312
#define SOURCE_SYMBOL      313
#define SQL_AFTER_GTIDS_SYMBOL      314
#define SQL_AFTER_MTS_GAPS_SYMBOL      315
#define SQL_BEFORE_GTIDS_SYMBOL      316
#define SQL_CACHE_SYMBOL      317
#define SQL_BUFFER_RESULT_SYMBOL      318
#define SQL_NO_CACHE_SYMBOL      319
#define SQL_THREAD_SYMBOL      320
#define STACKED_SYMBOL      321
#define STARTS_SYMBOL      322
#define STATS_AUTO_RECALC_SYMBOL      323
#define STATS_PERSISTENT_SYMBOL      324
#define STATS_SAMPLE_PAGES_SYMBOL      325
#define STATUS_SYMBOL      326
#define STORAGE_SYMBOL      327
#define STRING_SYMBOL      328
#define SUBCLASS_ORIGIN_SYMBOL      329
#define SUBDATE_SYMBOL      330
#define SUBJECT_SYMBOL      331
#define SUBPARTITION_SYMBOL      332
#define SUBPARTITIONS_SYMBOL      333
#define SUPER_SYMBOL      334
#define SUSPEND_SYMBOL      335
#define SWAPS_SYMBOL      336
#define SWITCHES_SYMBOL      337
#define TABLE_NAME_SYMBOL      338
#define TABLES_SYMBOL      339
#define TABLE_CHECKSUM_SYMBOL      340
#define TABLESPACE_SYMBOL      341
#define TEMPORARY_SYMBOL      342
#define TEMPTABLE_SYMBOL      343
#define TEXT_SYMBOL      344
#define THAN_SYMBOL      345
#define TRANSACTION_SYMBOL      346
#define TRIGGERS_SYMBOL      347
#define TIMESTAMP_SYMBOL      348
#define TIMESTAMP_ADD_SYMBOL      349
#define TIMESTAMP_DIFF_SYMBOL      350
#define TIME_SYMBOL      351
#define TYPES_SYMBOL      352
#define TYPE_SYMBOL      353
#define UDF_RETURNS_SYMBOL      354
#define FUNCTION_SYMBOL      355
#define UNCOMMITTED_SYMBOL      356
#define UNDEFINED_SYMBOL      357
#define UNDO_BUFFER_SIZE_SYMBOL      358
#define UNDOFILE_SYMBOL      359
#define UNKNOWN_SYMBOL      360
#define UNTIL_SYMBOL      361
#define USER_RESOURCES_SYMBOL      362
#define USER_SYMBOL      363
#define USE_FRM_SYMBOL      364
#define VARIABLES_SYMBOL      365
#define VIEW_SYMBOL      366
#define VALUE_SYMBOL      367
#define WARNINGS_SYMBOL      368
#define WAIT_SYMBOL      369
#define WEEK_SYMBOL      370
#define WORK_SYMBOL      371
#define WEIGHT_STRING_SYMBOL      372
#define X509_SYMBOL      373
#define XID_SYMBOL      374
#define XML_SYMBOL      375
#define YEAR_SYMBOL      376
#define ACCESSIBLE_SYMBOL      377
#define ADD_SYMBOL      378
#define ALL_SYMBOL      379
#define ALTER_SYMBOL      380
#define ANALYSE_SYMBOL      381
#define AND_SYMBOL      382
#define ASC_SYMBOL      383
#define ASENSITIVE_SYMBOL      384
#define BEFORE_SYMBOL      385
#define BETWEEN_SYMBOL      386
#define BIGINT_SYMBOL      387
#define BINARY_SYMBOL      388
#define BIN_NUM_SYMBOL      389
#define BLOB_SYMBOL      390
#define BLOCK_COMMENT      391
#define BOTH_SYMBOL      392
#define BY_SYMBOL      393
#define CALL_SYMBOL      394
#define CASCADE_SYMBOL      395
#define CASE_SYMBOL      396
#define CAST_SYMBOL      397
#define CHANGE_SYMBOL      398
#define CHARACTER_SYMBOL      399
#define CHAR_SYMBOL      400
#define CHECK_SYMBOL      401
#define COLLATE_SYMBOL      402
#define COLUMN_SYMBOL      403
#define COMMENT_RULE      404
#define CONDITION_SYMBOL      405
#define CONSTRAINT_SYMBOL      406
#define CONTINUE_SYMBOL      407
#define CONVERT_SYMBOL      408
#define COUNT_SYMBOL      409
#define CREATE_SYMBOL      410
#define CROSS_SYMBOL      411
#define CURDATE_SYMBOL      412
#define CURRENT_TIMESTAMP_SYMBOL      413
#define CURRENT_USER_SYMBOL      414
#define CURSOR_SYMBOL      415
#define CURTIME_SYMBOL      416
#define DASHDASH_COMMENT      417
#define DATABASES_SYMBOL      418
#define DATABASE_SYMBOL      419
#define DATE_ADD_INTERVAL_SYMBOL      420
#define DATE_ADD_SYMBOL      421
#define DATE_SUB_INTERVAL_SYMBOL      422
#define DATE_SUB_SYMBOL      423
#define DAYOFMONTH_SYMBOL      424
#define DAY_HOUR_SYMBOL      425
#define DAY_MICROSECOND_SYMBOL      426
#define DAY_MINUTE_SYMBOL      427
#define DAY_SECOND_SYMBOL      428
#define DECIMAL_NUM_SYMBOL      429
#define DECIMAL_SYMBOL      430
#define DECLARE_SYMBOL      431
#define DEC_SYMBOL      432
#define DEFAULT_SYMBOL      433
#define DELAYED_SYMBOL      434
#define DELETE_SYMBOL      435
#define DESCRIBE_SYMBOL      436
#define DESC_SYMBOL      437
#define DETERMINISTIC_SYMBOL      438
#define DISTINCTROW_SYMBOL      439
#define DISTINCT_SYMBOL      440
#define DROP_SYMBOL      441
#define DUAL_SYMBOL      442
#define EACH_SYMBOL      443
#define ELSEIF_SYMBOL      444
#define ELSE_SYMBOL      445
#define ENCLOSED_SYMBOL      446
#define END_OF_INPUT_SYMBOL      447
#define ESCAPED_SYMBOL      448
#define EXCHANGE_SYMBOL      449
#define EXISTS_SYMBOL      450
#define EXIT_SYMBOL      451
#define EXPIRE_SYMBOL      452
#define EXPLAIN_SYMBOL      453
#define EXTRACT_SYMBOL      454
#define FALSE_SYMBOL      455
#define FETCH_SYMBOL      456
#define FIELDS_SYMBOL      457
#define FLOAT4_SYMBOL      458
#define FLOAT8_SYMBOL      459
#define FLOAT_SYMBOL      460
#define FORCE_SYMBOL      461
#define FOREIGN_SYMBOL      462
#define FOR_SYMBOL      463
#define FRAC_SECOND_SYMBOL      464
#define FROM_SYMBOL      465
#define FULLTEXT_SYMBOL      466
#define GENERATED_SYMBOL      467
#define GET_SYMBOL      468
#define GRANT_SYMBOL      469
#define GROUP_CONCAT_SYMBOL      470
#define GROUP_SYMBOL      471
#define HAVING_SYMBOL      472
#define HIGH_PRIORITY_SYMBOL      473
#define HOUR_MICROSECOND_SYMBOL      474
#define HOUR_MINUTE_SYMBOL      475
#define HOUR_SECOND_SYMBOL      476
#define IF_SYMBOL      477
#define IGNORE_SYMBOL      478
#define INDEX_SYMBOL      479
#define INFILE_SYMBOL      480
#define INNER_SYMBOL      481
#define INOUT_SYMBOL      482
#define INSENSITIVE_SYMBOL      483
#define INSERT_SYMBOL      484
#define INT1_SYMBOL      485
#define INT2_SYMBOL      486
#define INT3_SYMBOL      487
#define INT4_SYMBOL      488
#define INT8_SYMBOL      489
#define INTEGER_SYMBOL      490
#define INTERVAL_SYMBOL      491
#define INTO_SYMBOL      492
#define INT_SYMBOL      493
#define IN_SYMBOL      494
#define IO_AFTER_GTIDS_SYMBOL      495
#define IO_BEFORE_GTIDS_SYMBOL      496
#define IO_THREAD_SYMBOL      497
#define IS_SYMBOL      498
#define ITERATE_SYMBOL      499
#define JOIN_SYMBOL      500
#define JSON_SEPARATOR_SYMBOL      501
#define KEYS_SYMBOL      502
#define KEY_SYMBOL      503
#define KILL_SYMBOL      504
#define LEADING_SYMBOL      505
#define LEAVE_SYMBOL      506
#define LEFT_SYMBOL      507
#define LIKE_SYMBOL      508
#define LIMIT_SYMBOL      509
#define LINEAR_SYMBOL      510
#define LINES_SYMBOL      511
#define LOAD_SYMBOL      512
#define LOCALTIMESTAMP_SYMBOL      513
#define LOCALTIME_SYMBOL      514
#define LOCATOR_SYMBOL      515
#define LOCK_SYMBOL      516
#define LONGBLOB_SYMBOL      517
#define LONGTEXT_SYMBOL      518
#define LONG_NUM_SYMBOL      519
#define LONG_SYMBOL      520
#define LOOP_SYMBOL      521
#define LOW_PRIORITY_SYMBOL      522
#define MASTER_BIND_SYMBOL      523
#define MASTER_SSL_VERIFY_SERVER_CERT_SYMBOL      524
#define MATCH_SYMBOL      525
#define MAXVALUE_SYMBOL      526
#define MAX_SYMBOL      527
#define MEDIUMBLOB_SYMBOL      528
#define MEDIUMINT_SYMBOL      529
#define MEDIUMTEXT_SYMBOL      530
#define MIDDLEINT_SYMBOL      531
#define MID_SYMBOL      532
#define MINUTE_MICROSECOND_SYMBOL      533
#define MINUTE_SECOND_SYMBOL      534
#define MIN_SYMBOL      535
#define ML_COMMENT_END      536
#define ML_COMMENT_HEAD      537
#define MODIFIES_SYMBOL      538
#define MOD_SYMBOL      539
#define NATURAL_SYMBOL      540
#define NCHAR_STRING_SYMBOL      541
#define NCHAR_TEXT      542
#define NDB_SYMBOL      543
#define NEG_SYMBOL      544
#define NONBLOCKING_SYMBOL      545
#define NOT2_SYMBOL      546
#define NOT_SYMBOL      547
#define NOW_SYMBOL      548
#define NO_WRITE_TO_BINLOG_SYMBOL      549
#define NULL2_SYMBOL      550
#define NULL_SYMBOL      551
#define NUMERIC_SYMBOL      552
#define OFFLINE_SYMBOL      553
#define ONLINE_SYMBOL      554
#define ONLY_SYMBOL      555
#define ON_SYMBOL      556
#define OPEN_CURLY_SYMBOL      557
#define OPEN_PAR_SYMBOL      558
#define OPTIMIZER_COSTS_SYMBOL      559
#define OPTIMIZE_SYMBOL      560
#define OPTIONALLY_SYMBOL      561
#define OPTION_SYMBOL      562
#define ORDER_SYMBOL      563
#define OR_SYMBOL      564
#define OUTER_SYMBOL      565
#define OUTFILE_SYMBOL      566
#define OUT_SYMBOL      567
#define PARAM_MARKER      568
#define POSITION_SYMBOL      569
#define POUND_COMMENT      570
#define PRECISION_SYMBOL      571
#define PRIMARY_SYMBOL      572
#define PROCEDURE_SYMBOL      573
#define PURGE_SYMBOL      574
#define RANGE_SYMBOL      575
#define READS_SYMBOL      576
#define READ_SYMBOL      577
#define READ_WRITE_SYMBOL      578
#define REAL_SYMBOL      579
#define REFERENCES_SYMBOL      580
#define REGEXP_SYMBOL      581
#define RELEASE_SYMBOL      582
#define RENAME_SYMBOL      583
#define REPEAT_SYMBOL      584
#define REPLACE_SYMBOL      585
#define REQUIRE_SYMBOL      586
#define RESIGNAL_SYMBOL      587
#define RESTRICT_SYMBOL      588
#define RETURN_SYMBOL      589
#define REVOKE_SYMBOL      590
#define RIGHT_SYMBOL      591
#define RLIKE_SYMBOL      592
#define SCHEMAS_SYMBOL      593
#define SCHEMA_SYMBOL      594
#define SECOND_MICROSECOND_SYMBOL      595
#define SELECT_SYMBOL      596
#define SEMICOLON_SYMBOL      597
#define SENSITIVE_SYMBOL      598
#define SEPARATOR_SYMBOL      599
#define SERVER_OPTIONS_SYMBOL      600
#define SESSION_USER_SYMBOL      601
#define SET_SYMBOL      602
#define SET_VAR_SYMBOL      603
#define SHOW_SYMBOL      604
#define SIGNAL_SYMBOL      605
#define SINGLE_QUOTED_TEXT      606
#define SMALLINT_SYMBOL      607
#define SPATIAL_SYMBOL      608
#define SPECIFIC_SYMBOL      609
#define SQLEXCEPTION_SYMBOL      610
#define SQLSTATE_SYMBOL      611
#define SQLWARNING_SYMBOL      612
#define SQL_BIG_RESULT_SYMBOL      613
#define SQL_CALC_FOUND_ROWS_SYMBOL      614
#define SQL_SMALL_RESULT_SYMBOL      615
#define SQL_SYMBOL      616
#define SQL_TSI_DAY_SYMBOL      617
#define SQL_TSI_FRAC_SECOND_SYMBOL      618
#define SQL_TSI_HOUR_SYMBOL      619
#define SQL_TSI_MINUTE_SYMBOL      620
#define SQL_TSI_MONTH_SYMBOL      621
#define SQL_TSI_QUARTER_SYMBOL      622
#define SQL_TSI_SECOND_SYMBOL      623
#define SQL_TSI_WEEK_SYMBOL      624
#define SQL_TSI_YEAR_SYMBOL      625
#define SSL_SYMBOL      626
#define STARTING_SYMBOL      627
#define STDDEV_POP_SYMBOL      628
#define STDDEV_SAMP_SYMBOL      629
#define STDDEV_SYMBOL      630
#define STD_SYMBOL      631
#define STORED_SYMBOL      632
#define STRAIGHT_JOIN_SYMBOL      633
#define SUBSTRING_SYMBOL      634
#define SUBSTR_SYMBOL      635
#define SUM_SYMBOL      636
#define SYSDATE_SYMBOL      637
#define SYSTEM_USER_SYMBOL      638
#define TABLE_REF_PRIORITY_SYMBOL      639
#define TABLE_SYMBOL      640
#define TERMINATED_SYMBOL      641
#define THEN_SYMBOL      642
#define TINYBLOB_SYMBOL      643
#define TINYINT_SYMBOL      644
#define TINYTEXT_SYMBOL      645
#define TO_SYMBOL      646
#define TRAILING_SYMBOL      647
#define TRIGGER_SYMBOL      648
#define TRIM_SYMBOL      649
#define TRUE_SYMBOL      650
#define UNDERLINE_SYMBOL      651
#define UNDO_SYMBOL      652
#define UNION_SYMBOL      653
#define UNIQUE_SYMBOL      654
#define UNLOCK_SYMBOL      655
#define UNSIGNED_SYMBOL      656
#define UPDATE_SYMBOL      657
#define USAGE_SYMBOL      658
#define USE_SYMBOL      659
#define USING_SYMBOL      660
#define UTC_DATE_SYMBOL      661
#define UTC_TIMESTAMP_SYMBOL      662
#define UTC_TIME_SYMBOL      663
#define VALIDATION_SYMBOL      664
#define VALUES_SYMBOL      665
#define VARBINARY_SYMBOL      666
#define VARCHARACTER_SYMBOL      667
#define VARCHAR_SYMBOL      668
#define VARIANCE_SYMBOL      669
#define VARYING_SYMBOL      670
#define VAR_POP_SYMBOL      671
#define VAR_SAMP_SYMBOL      672
#define VIRTUAL_SYMBOL      673
#define WHEN_SYMBOL      674
#define WHERE_SYMBOL      675
#define WHILE_SYMBOL      676
#define WITHOUT_SYMBOL      677
#define WITH_CUBE_SYMBOL      678
#define WITH_ROLLUP_SYMBOL      679
#define WITH_SYMBOL      680
#define WRITE_SYMBOL      681
#define XOR_SYMBOL      682
#define YEAR_MONTH_SYMBOL      683
#define ZEROFILL_SYMBOL      684
#define ALTER_TABLE_ITEM_TOKEN      685
#define ASSIGN_OPERATOR      686
#define AS_SYMBOL      687
#define AT_AT_SIGN_SYMBOL      688
#define AT_SIGN_SYMBOL      689
#define AT_TEXT_SUFFIX      690
#define BACK_TICK      691
#define BACK_TICK_QUOTED_ID      692
#define BIN_NUMBER      693
#define BITWISE_AND_OPERATOR      694
#define BITWISE_NOT_OPERATOR      695
#define BITWISE_OR_OPERATOR      696
#define BITWISE_XOR_OPERATOR      697
#define BIT_AND_SYMBOL      698
#define BIT_OR_SYMBOL      699
#define BIT_XOR_SYMBOL      700
#define CHANGE_MASTER_OPTIONS_TOKEN      701
#define CLOSE_CURLY_SYMBOL      702
#define CLOSE_PAR_SYMBOL      703
#define COLON_SYMBOL      704
#define COLUMN_ASSIGNMENT_LIST_TOKEN      705
#define COLUMN_INTERNAL_REF_TOKEN      706
#define COLUMN_NAME_TOKEN      707
#define COLUMN_REF_TOKEN      708
#define COMMA_SYMBOL      709
#define CONCAT_PIPES_SYMBOL      710
#define CREATE_ITEM_TOKEN      711
#define CURRENT_DATE_SYMBOL      712
#define CURRENT_TIME_SYMBOL      713
#define DATA_TYPE_TOKEN      714
#define DECIMAL_NUMBER      715
#define DIGIT      716
#define DIGITS      717
#define DIV_OPERATOR      718
#define DIV_SYMBOL      719
#define DOT_IDENTIFIER      720
#define DOT_SYMBOL      721
#define DOUBLE_DASH      722
#define DOUBLE_QUOTE      723
#define DOUBLE_QUOTED_TEXT      724
#define DOUBLE_SYMBOL      725
#define ENGINE_REF_TOKEN      726
#define EQUAL_OPERATOR      727
#define ESCAPE_OPERATOR      728
#define EVENT_NAME_TOKEN      729
#define EVENT_REF_TOKEN      730
#define EXPRESSION_TOKEN      731
#define FLOAT_NUMBER      732
#define FUNCTION_CALL_TOKEN      733
#define FUNCTION_NAME_TOKEN      734
#define FUNCTION_REF_TOKEN      735
#define GREATER_OR_EQUAL_OPERATOR      736
#define GREATER_THAN_OPERATOR      737
#define HEXDIGIT      738
#define HEX_NUMBER      739
#define IDENTIFIER      740
#define INDEX_HINT_LIST_TOKEN      741
#define INDEX_NAME_TOKEN      742
#define INDEX_REF_TOKEN      743
#define INT_NUMBER      744
#define INVALID_INPUT      745
#define JOIN_EXPR_TOKEN      746
#define JSON_UNQUOTED_SEPARATOR_SYMBOL      747
#define KEY_CACHE_LIST_TOKEN      748
#define KEY_CACHE_PARTITION_TOKEN      749
#define LABEL_TOKEN      750
#define LESS_OR_EQUAL_OPERATOR      751
#define LESS_THAN_OPERATOR      752
#define LETTER_WHEN_UNQUOTED      753
#define LETTER_WHEN_UNQUOTED_NO_DIGIT      754
#define LINEBREAK      755
#define LOGFILE_GROUP_NAME_TOKEN      756
#define LOGFILE_GROUP_OPTIONS_TOKEN      757
#define LOGFILE_GROUP_REF_TOKEN      758
#define LOGICAL_AND_OPERATOR      759
#define LOGICAL_NOT_OPERATOR      760
#define LOGICAL_OR_OPERATOR      761
#define LONG_NUMBER      762
#define MINUS_OPERATOR      763
#define MOD_OPERATOR      764
#define MULTILINE_COMMENT      765
#define MULT_OPERATOR      766
#define NOT_EQUAL2_OPERATOR      767
#define NOT_EQUAL_OPERATOR      768
#define NULL_SAFE_EQUAL_OPERATOR      769
#define NUMBER      770
#define PAR_EXPRESSION_TOKEN      771
#define PLUS_OPERATOR      772
#define PRIVILEGE_TARGET_TOKEN      773
#define PROCEDURE_NAME_TOKEN      774
#define PROCEDURE_REF_TOKEN      775
#define ROUTINE_ALTER_OPTIONS      776
#define ROUTINE_CREATE_OPTIONS      777
#define RUNTIME_FUNCTION_TOKEN      778
#define SCHEMA_NAME_TOKEN      779
#define SCHEMA_REF_TOKEN      780
#define SELECT_EXPR_TOKEN      781
#define SERVER_NAME_TOKEN      782
#define SERVER_REF_TOKEN      783
#define SHIFT_LEFT_OPERATOR      784
#define SHIFT_RIGHT_OPERATOR      785
#define SIMPLE_IDENTIFIER      786
#define SINGLE_QUOTE      787
#define SLAVE_THREAD_OPTIONS_TOKEN      788
#define SOME_SYMBOL      789
#define STRING_NO_LINEBREAK_TOKEN      790
#define STRING_TOKEN      791
#define SUBQUERY_TOKEN      792
#define TABLESPACE_NAME_TOKEN      793
#define TABLESPACE_OPTIONS_TOKEN      794
#define TABLESPACE_REF_TOKEN      795
#define TABLE_NAME_TOKEN      796
#define TABLE_REF_TOKEN      797
#define TRIGGER_NAME_TOKEN      798
#define TRIGGER_REF_TOKEN      799
#define UDF_CALL_TOKEN      800
#define UDF_NAME_TOKEN      801
#define ULONGLONG_NUMBER      802
#define UNDERSCORE_CHARSET      803
#define VERSION_COMMENT      804
#define VERSION_COMMENT_END      805
#define VERSION_COMMENT_INTRODUCER      806
#define VERSION_COMMENT_START_TOKEN      807
#define VERSION_COMMENT_TAIL      808
#define VIEW_NAME_TOKEN      809
#define VIEW_REF_TOKEN      810
#define WHITESPACE      811
#define XA_ID_TOKEN      812
#ifdef	EOF
#undef	EOF
#define	EOF	ANTLR3_TOKEN_EOF
#endif

#ifndef TOKENSOURCE
#define TOKENSOURCE(lxr) lxr->pLexer->rec->state->tokSource
#endif

/* End of token definitions for MySQLLexer
 * =============================================================================
 */
/** } */

#ifdef __cplusplus
}
#endif

#endif

/* END - Note:Keep extra line feed to satisfy UNIX systems */
